| Title: | Proactive Conservation Index |
|---|---|
| Description: | Calculates the Proactive Conservation Index, a new tool to prioritize species for conservation, which can incorporate information about future threats. |
| Authors: | Gabriel Henrique de Oliveira Caetano [aut, cre], Uri Roll [aut], Shai Meiri [aut] |
| Maintainer: | Gabriel Henrique de Oliveira Caetano <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-05-22 08:44:03 UTC |
| Source: | https://github.com/cran/pciR |
optim_weights Optimizes weights for calculating Proactive Conservation Index,
optim_weights( sp, var_out, var_in = NULL, weight_out = NULL, weight_in = NULL, reference, type = "both", ... )optim_weights( sp, var_out, var_in = NULL, weight_out = NULL, weight_in = NULL, reference, type = "both", ... )
sp |
character. Names of the taxa being evaluated. |
var_out |
numeric. Threat variables. higher values must indicate increased threat. |
var_in |
numeric. Interacting variables. Will modulate the effect of threat variables. |
weight_out |
numeric. Weights for threat variables |
weight_in |
numeric. Matrix of weights for the combination of interacting variables and threat variables. |
reference |
numeric. Threat reference towards which weights will be optimized. |
type |
character. Optimize weights for threat variables ("out"), for interacting variables ("in") or for both ("both"). |
... |
additional arguments to be passed to function 'optim'. |
The Pearson correlation between the calculated pci and 'reference' is displayed as the weights are optimized.
Vector ("out"), matrix ("in") or list ("both") with optimal weights.
# This function takes too long to run here. #See vignette for a detailed explanation on how to use it.# This function takes too long to run here. #See vignette for a detailed explanation on how to use it.
pci Calculates the Proactive Conservation Index, a new tool to prioritize species for conservation, which incorporates information about future threats.
pci(sp, var_out, var_in = NULL, weight_out = NULL, weight_in = NULL)pci(sp, var_out, var_in = NULL, weight_out = NULL, weight_in = NULL)
sp |
character. Names of the taxa being evaluated. |
var_out |
numeric. Threat variables. higher values must indicate increased threat. |
var_in |
numeric. Interacting variables. Will modulate the effect of threat variables. |
weight_out |
numeric. Weights for threat variables |
weight_in |
numeric. Matrix of weights for the combination of interacting variables and threat variables. |
Data frame with PCI and rank.
# Invert variables that are negatively correlated with conservation priority vert_df$inv_range_area <- 1/vert_df$range_area vert_df$inv_brood_size <- 1/vert_df$brood_size vert_df$inv_protected_area <- 1/((vert_df$protected_area*vert_df$range_area+0.0001)) # Select trait variables traits_vertebrates <- vert_df[c("body_mass", "inv_range_area", "inv_brood_size", "inv_protected_area", "AHI")] # Select threat variables for the year 2100, under scenarion SSP 5.85 threats_2100_585 <- vert_df[c("clim_2100_585", "landuse_2100_585", "popdens_2100_585", "inv_threat")] # Calculate PCI vertebrates_pci <- pci(sp = vert_df$binomial, var_out = threats_2100_585, var_in = traits_vertebrates)# Invert variables that are negatively correlated with conservation priority vert_df$inv_range_area <- 1/vert_df$range_area vert_df$inv_brood_size <- 1/vert_df$brood_size vert_df$inv_protected_area <- 1/((vert_df$protected_area*vert_df$range_area+0.0001)) # Select trait variables traits_vertebrates <- vert_df[c("body_mass", "inv_range_area", "inv_brood_size", "inv_protected_area", "AHI")] # Select threat variables for the year 2100, under scenarion SSP 5.85 threats_2100_585 <- vert_df[c("clim_2100_585", "landuse_2100_585", "popdens_2100_585", "inv_threat")] # Calculate PCI vertebrates_pci <- pci(sp = vert_df$binomial, var_out = threats_2100_585, var_in = traits_vertebrates)
A data set containing data on threat correlates for 33565 global terrestrial vertebrates.
vert_dfvert_df
A data frame with 33565 rows and 21 variables:
character. Species binomial name
character. Taxonomic class
character. Taxonomic family
numeric. Area of distribution range, in km2
numeric. Maximum body mass, in grams
numeric. Maximum number of offspring per brood
numeric. Proportion of species range overlapping with protected area under category I to IV
numeric. Artificial Habitat Intolerance, an index calculated from the IUCN Red List data on habitat use
character. IUCN Red List threat category in July 2022
numeric. Proportion of species range lost due to climate change in 2050, under SSP 2.45 scenario
numeric. Proportion of species range lost due to climate change in 2100, under SSP 2.45 scenario
numeric. Proportion of species range lost due to climate change in 2050, under SSP 5.85 scenario
numeric. Proportion of species range lost due to climate change in 2100, under SSP 5.85 scenario
numeric. Proportion of species range lost due to land use change in 2050, under SSP 2.45 scenario
numeric. Proportion of species range lost due to land use change in 2100, under SSP 2.45 scenario
numeric. Proportion of species range lost due to land use change in 2050, under SSP 5.85 scenario
numeric. Proportion of species range lost due to land use change in 2100, under SSP 5.85 scenario
numeric. Mean human population density in 2050, under SSP 2.45 scenario
numeric. Mean human population density in 2100, under SSP 2.45 scenario
numeric. Mean human population density in 2050, under SSP 5.85 scenario
numeric. Mean human population density in 2100, under SSP 5.85 scenario
numeric. Proportion of species range under high or very high threat of biological invasion in 2100 under A3 scenario