| Type: | Package |
| Title: | Proactive Conservation Index |
| Version: | 1.0.0 |
| Description: | Calculates the Proactive Conservation Index, a new tool to prioritize species for conservation, which can incorporate information about future threats. |
| License: | GPL-3 |
| Encoding: | UTF-8 |
| LazyData: | true |
| Imports: | caret |
| Depends: | R (≥ 4.1.0) |
| Suggests: | rmarkdown, knitr |
| VignetteBuilder: | knitr |
| RoxygenNote: | 7.3.2 |
| NeedsCompilation: | no |
| Packaged: | 2026-04-17 12:32:38 UTC; gabri |
| Author: | Gabriel Henrique de Oliveira Caetano [aut, cre], Uri Roll [aut], Shai Meiri [aut] |
| Maintainer: | Gabriel Henrique de Oliveira Caetano <gabrielhoc@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-04-21 19:32:24 UTC |
Optimizes weighting for the calculation of Proactive Conservation Index
Description
optim_weights Optimizes weights for calculating Proactive Conservation Index,
Usage
optim_weights(
sp,
var_out,
var_in = NULL,
weight_out = NULL,
weight_in = NULL,
reference,
type = "both",
...
)
Arguments
sp |
character. Names of the taxa being evaluated. |
var_out |
numeric. Threat variables. higher values must indicate increased threat. |
var_in |
numeric. Interacting variables. Will modulate the effect of threat variables. |
weight_out |
numeric. Weights for threat variables |
weight_in |
numeric. Matrix of weights for the combination of interacting variables and threat variables. |
reference |
numeric. Threat reference towards which weights will be optimized. |
type |
character. Optimize weights for threat variables ("out"), for interacting variables ("in") or for both ("both"). |
... |
additional arguments to be passed to function 'optim'. |
Details
The Pearson correlation between the calculated pci and 'reference' is displayed as the weights are optimized.
Value
Vector ("out"), matrix ("in") or list ("both") with optimal weights.
Examples
# This function takes too long to run here.
#See vignette for a detailed explanation on how to use it.
Calculates Proactive Conservation Index
Description
pci Calculates the Proactive Conservation Index, a new tool to prioritize species for conservation, which incorporates information about future threats.
Usage
pci(sp, var_out, var_in = NULL, weight_out = NULL, weight_in = NULL)
Arguments
sp |
character. Names of the taxa being evaluated. |
var_out |
numeric. Threat variables. higher values must indicate increased threat. |
var_in |
numeric. Interacting variables. Will modulate the effect of threat variables. |
weight_out |
numeric. Weights for threat variables |
weight_in |
numeric. Matrix of weights for the combination of interacting variables and threat variables. |
Value
Data frame with PCI and rank.
Examples
# Invert variables that are negatively correlated with conservation priority
vert_df$inv_range_area <- 1/vert_df$range_area
vert_df$inv_brood_size <- 1/vert_df$brood_size
vert_df$inv_protected_area <- 1/((vert_df$protected_area*vert_df$range_area+0.0001))
# Select trait variables
traits_vertebrates <-
vert_df[c("body_mass",
"inv_range_area",
"inv_brood_size",
"inv_protected_area",
"AHI")]
# Select threat variables for the year 2100, under scenarion SSP 5.85
threats_2100_585 <-
vert_df[c("clim_2100_585",
"landuse_2100_585",
"popdens_2100_585",
"inv_threat")]
# Calculate PCI
vertebrates_pci <-
pci(sp = vert_df$binomial,
var_out = threats_2100_585,
var_in = traits_vertebrates)
Threat data for 33565 global terrestrial vertebrates.
Description
A data set containing data on threat correlates for 33565 global terrestrial vertebrates.
Usage
vert_df
Format
A data frame with 33565 rows and 21 variables:
- binomial
character. Species binomial name
- class
character. Taxonomic class
- family
character. Taxonomic family
- range_area
numeric. Area of distribution range, in km2
- body_mass
numeric. Maximum body mass, in grams
- brood_size
numeric. Maximum number of offspring per brood
- protected_area
numeric. Proportion of species range overlapping with protected area under category I to IV
- AHI
numeric. Artificial Habitat Intolerance, an index calculated from the IUCN Red List data on habitat use
- iucn_cat
character. IUCN Red List threat category in July 2022
- clim_2050_245
numeric. Proportion of species range lost due to climate change in 2050, under SSP 2.45 scenario
- clim_2100_245
numeric. Proportion of species range lost due to climate change in 2100, under SSP 2.45 scenario
- clim_2050_585
numeric. Proportion of species range lost due to climate change in 2050, under SSP 5.85 scenario
- clim_2100_585
numeric. Proportion of species range lost due to climate change in 2100, under SSP 5.85 scenario
- landuse_2050_245
numeric. Proportion of species range lost due to land use change in 2050, under SSP 2.45 scenario
- landuse_2100_245
numeric. Proportion of species range lost due to land use change in 2100, under SSP 2.45 scenario
- landuse_2050_585
numeric. Proportion of species range lost due to land use change in 2050, under SSP 5.85 scenario
- landuse_2100_585
numeric. Proportion of species range lost due to land use change in 2100, under SSP 5.85 scenario
- popdens_2050_245
numeric. Mean human population density in 2050, under SSP 2.45 scenario
- popdens_2100_245
numeric. Mean human population density in 2100, under SSP 2.45 scenario
- popdens_2050_585
numeric. Mean human population density in 2050, under SSP 5.85 scenario
- popdens_2100_585
numeric. Mean human population density in 2100, under SSP 5.85 scenario
- inv_threat
numeric. Proportion of species range under high or very high threat of biological invasion in 2100 under A3 scenario